@@ -180,10 +180,13 @@ def mirror_postgres_db(c):
     localtempfile = download_postgres_db(c)
     c.local('dropdb --if-exists {env.db_name}'.format(env=c.env))
     c.local('createdb {env.db_name}'.format(env=c.env))
-    # with c.settings(warn_only=True):
 
     # Using sudo here avoids permission errors relating to extensions.
-    c.local('pg_restore --dbname={env.db_name} {localtempfile}'.format(
+    #
+    # Tried removing the above drop and create and adding --clean --create
+    # below, but I get a whole bunch of errors relating to things already being
+    # in the database.
+    c.local('pg_restore --no-owner --no-privileges --dbname={env.db_name} {localtempfile}'.format(
         env=c.env, localtempfile=localtempfile), warn=True)
 
     c.local("""psql {env.db_name} -c "update django_site set domain = '127.0.0.1:8000'" """.format(env=c.env), warn=True)
